# clirail: command line interface to iRail
# Copyright © 2019 Midgard
# License: GPLv3+

from .config import LANG


_messages = {
	"en": {
		"public_log": """This program uses the iRail API. All requests to iRail are \x1b[1mpublically logged\x1b[0m.
Learn more at the iRail API documentation: https://docs.irail.be/#log-and-feedback-data
If you are okay with this, press Enter to continue. Otherwise, press Ctrl+C.""",

		"downloading_stations": "Downloading list of stations… This only needs to be done once.",

		"didnt_understand_moment": """Didn’t understand moment “{moment}”, try writing it in another way.
Examples of easily understood moments are “8:30” and “2019-01-01, 8:30”.""",

		"canceled": "canceled",

		"departure_in": "Departure in {station}",
		"departure_in_w_code": "Departure in {station} ({telegraphic_code})",

		"train": "train",
		"destination": "destination",
		"platform": "platform",
		"departure": "departure",
		"duration": "dur.",
		"dep_arr": "dep/arr",
		"station": "station",
		"towards": "towards",

		"go_to_next_station": "go to the next station on your own",

		"m_duration_fmt": "{}m",
		"hm_duration_fmt": "{}h{:02}m",
		"m_delay_fmt": "{}",
		"hm_delay_fmt": "{}h{:02}",

		"delay_0": "On time",
		"delay_1": "1-6m delay",
		"delay_6": "6-30m delay",
		"delay_30": ">30m delay",
		"delay_canceled": "Canceled",
		"departed": "Departed",
		"not_yet_departed": "Not yet departed",
		"canceled_explanation": "For canceled trains this means: should have departed by now",

		"day_of_week_0": "Monday",
		"day_of_week_1": "Tuesday",
		"day_of_week_2": "Wednesday",
		"day_of_week_3": "Thursday",
		"day_of_week_4": "Friday",
		"day_of_week_5": "Saturday",
		"day_of_week_6": "Sunday",

		"help": """clirail: command line interface to iRail

Usage:
  clirail <station> ['' <moment>]                   List of trains departing in station
  clirail <from_station> <to_station> [<moment>]    Route planning
  clirail                                           Analyse current timeliness in a few stations
Omit the <moment> for ASAP departures.

Usage example:
  clirail gent flv         Plan route from Gent-Sint-Pieters to Leuven

Give either the station's name or its telegraphic code. Names are matched fuzzily and intuitively.
Telegraphic codes are short and sweet, you can learn them by looking at liveboards.

If <moment> is just a time, it will be considered as today, even though in some cases it would make
more sense to consider it as tomorrow (e.g. at 11 PM planning a route with departure at 7 AM).""",
	},

	"nl": {
		"public_log": """Dit programma gebruikt de iRail-API. Alle opzoekingen bij iRail worden \x1b[1mpubliek gelogd\x1b[0m.
Lees meer in de iRail-API-documentatie (in het Engels): https://docs.irail.be/#log-and-feedback-data
Als dit oké is, druk dan Enter om door te gaan. Druk anders Ctrl+C.""",

		"downloading_stations": "Lijst van stations downloaden… Dit moet maar één keer gebeuren.",

		"didnt_understand_moment": """Moment “{moment}” werd niet begrepen, probeer het eens op een andere manier te schrijven.
Voorbeelden van gemakkelijk te begrijpen momenten zijn “8:30” en “2019-01-01, 8:30”.""",

		"canceled": "afgeschaft",

		"departure_in": "Vertrek in {station}",
		"departure_in_w_code": "Vertrek in {station} ({telegraphic_code})",

		"train": "trein",
		"destination": "bestemming",
		"platform": "spoor",
		"departure": "vertrek",
		"duration": "duur",
		"dep_arr": "ver/aan",
		"station": "station",
		"towards": "richting",

		"go_to_next_station": "raak zelf in volgende station",

		"m_duration_fmt": "{}m",
		"hm_duration_fmt": "{}u{:02}m",
		"m_delay_fmt": "{}",
		"hm_delay_fmt": "{}u{:02}",

		"delay_0": "Op tijd",
		"delay_1": "1-6m vertraging",
		"delay_6": "6-30m vertraging",
		"delay_30": ">30m vertraging",
		"delay_canceled": "Afgeschaft",
		"departed": "Vertrokken",
		"not_yet_departed": "Nog niet vertrokken",
		"canceled_explanation": "Voor afgeschafte treinen betekent dit: had nu al vertrokken moeten zijn",

		"day_of_week_0": "maandag",
		"day_of_week_1": "dinsdag",
		"day_of_week_2": "woensdag",
		"day_of_week_3": "donderdag",
		"day_of_week_4": "vrijdag",
		"day_of_week_5": "zaterdag",
		"day_of_week_6": "zondag",

		"help": """clirail: commandolijninterface voor iRail

Syntaxis:
  clirail <station> ['' <vertrek>]                  Vertrekkende treinen in station
  clirail <van_station> <naar_station> [<vertrek>]  Routeplanning
  clirail                                           Analyseer huidige stiptheid in een paar stations
Laat <vertrek> weg voor "zo snel mogelijk".

Voorbeeld:
  clirail gent flv         Plan route van Gent-Sint-Pieters naar Leuven

Geef de naam of telegrafische code van een station. Namen worden gezocht op intuïtieve manier en
moeten niet volledig correct gespeld zijn. Telegrafische codes zijn kort en handig, ze worden
getoond bij de lijst van vertrekkende treinen in een station, zo kun je ze leren.

Als <vertrek> enkel een tijdtip is, wordt het beschouwd als vandaag, ook al zou je soms verwachten
dat het morgen is (bv. om 23 uur een route plannen met vertrek om 7 uur 's ochtends)."""
	}
}

def t(key):
	return _messages \
		.get(LANG, _messages["en"]) \
		.get(key, "Missing translation for " + key)



# clirail: command line interface to iRail
# Copyright © 2019 Midgard
# License: GPLv3+

# Data from Wikidata

station_codes = {
	"AND":   "http://irail.be/stations/NMBS/008821089",
	"ANS":   "http://irail.be/stations/NMBS/008841202",
	"ANTC":  "http://irail.be/stations/NMBS/008821006",
	"ATH":   "http://irail.be/stations/NMBS/008886009",
	"BGWV":  "http://irail.be/stations/NMBS/008811734",
	"BUDA":  "http://irail.be/stations/NMBS/008811148",
	"FAD":   "http://irail.be/stations/NMBS/008893526",
	"FAK":   "http://irail.be/stations/NMBS/008831039",
	"FAN":   "http://irail.be/stations/NMBS/008892734",
	"FAO":   "http://irail.be/stations/NMBS/008874583",
	"FAP":   "http://irail.be/stations/NMBS/008886561",
	"FAR":   "http://irail.be/stations/NMBS/008892288",
	"FAT":   "http://irail.be/stations/NMBS/008822517",
	"FBC":   "http://irail.be/stations/NMBS/008883006",
	"FBCK":  "http://irail.be/stations/NMBS/008813037",
	"FBCL":  "http://irail.be/stations/NMBS/008813003",
	"FBCO":  "http://irail.be/stations/NMBS/008813045",
	"FBD":   "http://irail.be/stations/NMBS/008814258",
	"FBG":   "http://irail.be/stations/NMBS/008886066",
	"FBK":   "http://irail.be/stations/NMBS/008891405",
	"FBL":   "http://irail.be/stations/NMBS/008812021",
	"FBMZ":  "http://irail.be/stations/NMBS/008814001",
	"FBN":   "http://irail.be/stations/NMBS/008812005",
	"FBNL":  "http://irail.be/stations/NMBS/008819406",
	"FBR":   "http://irail.be/stations/NMBS/008894748",
	"FBSG":  "http://irail.be/stations/NMBS/008812211",
	"FBSM":  "http://irail.be/stations/NMBS/008811916",
	"FBV":   "http://irail.be/stations/NMBS/008894151",
	"FBX":   "http://irail.be/stations/NMBS/008843901",
	"FCA":   "http://irail.be/stations/NMBS/008884889",
	"FCB":   "http://irail.be/stations/NMBS/008893542",
	"FCH":   "http://irail.be/stations/NMBS/008842036",
	"FCL":   "http://irail.be/stations/NMBS/008874005",
	"FCR":   "http://irail.be/stations/NMBS/008872009",
	"FCRO":  "http://irail.be/stations/NMBS/008872066",
	"FCS":   "http://irail.be/stations/NMBS/008883212",
	"FCV":   "http://irail.be/stations/NMBS/008821121",
	"FCZ":   "http://irail.be/stations/NMBS/008883220",
	"FD":    "http://irail.be/stations/NMBS/008892106",
	"FDD":   "http://irail.be/stations/NMBS/008895802",
	"FDF":   "http://irail.be/stations/NMBS/008822210",
	"FDG":   "http://irail.be/stations/NMBS/008811213",
	"FDI":   "http://irail.be/stations/NMBS/008871381",
	"FDK":   "http://irail.be/stations/NMBS/008892338",
	"FDL":   "http://irail.be/stations/NMBS/008844545",
	"FDM":   "http://irail.be/stations/NMBS/008893518",
	"FDN":   "http://irail.be/stations/NMBS/008892601",
	"FDO":   "http://irail.be/stations/NMBS/008892031",
	"FDR":   "http://irail.be/stations/NMBS/008893401",
	"FDT":   "http://irail.be/stations/NMBS/008831401",
	"FEB":   "http://irail.be/stations/NMBS/008891157",
	"FED":   "http://irail.be/stations/NMBS/008895711",
	"FEI":   "http://irail.be/stations/NMBS/008892627",
	"FEK":   "http://irail.be/stations/NMBS/008812161",
	"FEM":   "http://irail.be/stations/NMBS/008811270",
	"FEO":   "http://irail.be/stations/NMBS/008861119",
	"FES":   "http://irail.be/stations/NMBS/008821402",
	"FET":   "http://irail.be/stations/NMBS/008811288",
	"FEV":   "http://irail.be/stations/NMBS/008886058",
	"FFA":   "http://irail.be/stations/NMBS/008886041",
	"FFC":   "http://irail.be/stations/NMBS/008874567",
	"FFM":   "http://irail.be/stations/NMBS/008883238",
	"FFV":   "http://irail.be/stations/NMBS/008883121",
	"FFW":   "http://irail.be/stations/NMBS/008861127",
	"FGA":   "http://irail.be/stations/NMBS/008892643",
	"FGDM":  "http://irail.be/stations/NMBS/008893120",
	"FGE":   "http://irail.be/stations/NMBS/008895240",
	"FGED":  "http://irail.be/stations/NMBS/008895257",
	"FGH":   "http://irail.be/stations/NMBS/008884004",
	"FGM":   "http://irail.be/stations/NMBS/008895620",
	"FGN":   "http://irail.be/stations/NMBS/008822145",
	"FGO":   "http://irail.be/stations/NMBS/008814167",
	"FGP":   "http://irail.be/stations/NMBS/008871373",
	"FGRA":  "http://irail.be/stations/NMBS/008895505",
	"FGSP":  "http://irail.be/stations/NMBS/008892007",
	"FGU":   "http://irail.be/stations/NMBS/008814340",
	"FGY":   "http://irail.be/stations/NMBS/008872520",
	"FH":    "http://irail.be/stations/NMBS/008814308",
	"FHA":   "http://irail.be/stations/NMBS/008895869",
	"FHF":   "http://irail.be/stations/NMBS/008822277",
	"FHI":   "http://irail.be/stations/NMBS/008891645",
	"FHK":   "http://irail.be/stations/NMBS/008891165",
	"FHL":   "http://irail.be/stations/NMBS/008896115",
	"FHS":   "http://irail.be/stations/NMBS/008831005",
	"FHT":   "http://irail.be/stations/NMBS/008821717",
	"FHZ":   "http://irail.be/stations/NMBS/008895430",
	"FI":    "http://irail.be/stations/NMBS/008896503",
	"FIA":   "http://irail.be/stations/NMBS/008891132",
	"FID":   "http://irail.be/stations/NMBS/008895729",
	"FIE":   "http://irail.be/stations/NMBS/008831138",
	"FIH":   "http://irail.be/stations/NMBS/008881125",
	"FIK":   "http://irail.be/stations/NMBS/008892452",
	"FIL":   "http://irail.be/stations/NMBS/008883436",
	"FIT":   "http://irail.be/stations/NMBS/008821964",
	"FIU":   "http://irail.be/stations/NMBS/008881158",
	"FIZ":   "http://irail.be/stations/NMBS/008822426",
	"FJE":   "http://irail.be/stations/NMBS/008821667",
	"FJL":   "http://irail.be/stations/NMBS/008844321",
	"FJR":   "http://irail.be/stations/NMBS/008881166",
	"FJS":   "http://irail.be/stations/NMBS/008874724",
	"FJT":   "http://irail.be/stations/NMBS/008812047",
	"FKB":   "http://irail.be/stations/NMBS/008812237",
	"FKE":   "http://irail.be/stations/NMBS/008892650",
	"FKG":   "http://irail.be/stations/NMBS/008831765",
	"FKI":   "http://irail.be/stations/NMBS/008821311",
	"FKK":   "http://irail.be/stations/NMBS/008891660",
	"FKLO":  "http://irail.be/stations/NMBS/008893708",
	"FKO":   "http://irail.be/stations/NMBS/008895778",
	"FKP":   "http://irail.be/stations/NMBS/008822053",
	"FKR":   "http://irail.be/stations/NMBS/008893013",
	"FKRG":  "http://irail.be/stations/NMBS/008812013",
	"FKS":   "http://irail.be/stations/NMBS/008812260",
	"FKTH":  "http://irail.be/stations/NMBS/008821444",
	"FKV":   "http://irail.be/stations/NMBS/008895612",
	"FKW":   "http://irail.be/stations/NMBS/008812146",
	"FKY":   "http://irail.be/stations/NMBS/008831781",
	"FL":    "http://irail.be/stations/NMBS/008841004",
	"FLB":   "http://irail.be/stations/NMBS/008814332",
	"FLC":   "http://irail.be/stations/NMBS/008892205",
	"FLD":   "http://irail.be/stations/NMBS/008833605",
	"FLE":   "http://irail.be/stations/NMBS/008895067",
	"FLF":   "http://irail.be/stations/NMBS/008861135",
	"FLGP":  "http://irail.be/stations/NMBS/008841525",
	"FLK":   "http://irail.be/stations/NMBS/008894201",
	"FLM":   "http://irail.be/stations/NMBS/008892056",
	"FLN":   "http://irail.be/stations/NMBS/008886504",
	"FLR":   "http://irail.be/stations/NMBS/008821600",
	"FLS":   "http://irail.be/stations/NMBS/008895000",
	"FLT":   "http://irail.be/stations/NMBS/008891140",
	"FLU":   "http://irail.be/stations/NMBS/008871308",
	"FLV":   "http://irail.be/stations/NMBS/008833001",
	"FLW":   "http://irail.be/stations/NMBS/008891629",
	"FLZ":   "http://irail.be/stations/NMBS/008886348",
	"FM":    "http://irail.be/stations/NMBS/008822004",
	"FMB":   "http://irail.be/stations/NMBS/008822814",
	"FMC":   "http://irail.be/stations/NMBS/008885704",
	"FMD":   "http://irail.be/stations/NMBS/008822137",
	"FME":   "http://irail.be/stations/NMBS/008896305",
	"FMHT":  "http://irail.be/stations/NMBS/008812120",
	"FML":   "http://irail.be/stations/NMBS/008893039",
	"FMN":   "http://irail.be/stations/NMBS/008882701",
	"FMR":   "http://irail.be/stations/NMBS/008871100",
	"FMS":   "http://irail.be/stations/NMBS/008881000",
	"FMT":   "http://irail.be/stations/NMBS/008861150",
	"FMU":   "http://irail.be/stations/NMBS/008841442",
	"FMV":   "http://irail.be/stations/NMBS/008893252",
	"FNE":   "http://irail.be/stations/NMBS/008881190",
	"FNF":   "http://irail.be/stations/NMBS/008861143",
	"FNG":   "http://irail.be/stations/NMBS/008883311",
	"FNH":   "http://irail.be/stations/NMBS/008821048",
	"FNLB":  "http://irail.be/stations/NMBS/008821063",
	"FNM":   "http://irail.be/stations/NMBS/008896925",
	"FNN":   "http://irail.be/stations/NMBS/008895760",
	"FNO":   "http://irail.be/stations/NMBS/008845203",
	"FNR":   "http://irail.be/stations/NMBS/008863008",
	"FNT":   "http://irail.be/stations/NMBS/008885522",
	"FNU":   "http://irail.be/stations/NMBS/008894714",
	"FNV":   "http://irail.be/stations/NMBS/008844230",
	"FNVT":  "http://irail.be/stations/NMBS/008814209",
	"FNW":   "http://irail.be/stations/NMBS/008893534",
	"FNY":   "http://irail.be/stations/NMBS/008883022",
	"FNZ":   "http://irail.be/stations/NMBS/008892692",
	"FNZD":  "http://irail.be/stations/NMBS/008821196",
	"FO":    "http://irail.be/stations/NMBS/008814373",
	"FOB":   "http://irail.be/stations/NMBS/008822475",
	"FOE":   "http://irail.be/stations/NMBS/008824158",
	"FOI":   "http://irail.be/stations/NMBS/008896412",
	"FOL":   "http://irail.be/stations/NMBS/008814241",
	"FOO":   "http://irail.be/stations/NMBS/008893047",
	"FOST":  "http://irail.be/stations/NMBS/008814118",
	"FOW":   "http://irail.be/stations/NMBS/008821725",
	"FPH":   "http://irail.be/stations/NMBS/008822269",
	"FPL":   "http://irail.be/stations/NMBS/008884855",
	"FPM":   "http://irail.be/stations/NMBS/008884632",
	"FPN":   "http://irail.be/stations/NMBS/008871365",
	"FPNO":  "http://irail.be/stations/NMBS/008815016",
	"FPO":   "http://irail.be/stations/NMBS/008891116",
	"FPP":   "http://irail.be/stations/NMBS/008896735",
	"FPS":   "http://irail.be/stations/NMBS/008844206",
	"FPT":   "http://irail.be/stations/NMBS/008892080",
	"FQ":    "http://irail.be/stations/NMBS/008884335",
	"FQR":   "http://irail.be/stations/NMBS/008884541",
	"FQT":   "http://irail.be/stations/NMBS/008893567",
	"FR":    "http://irail.be/stations/NMBS/008891009",
	"FRA":   "http://irail.be/stations/NMBS/008822160",
	"FRB":   "http://irail.be/stations/NMBS/008814365",
	"FRD":   "http://irail.be/stations/NMBS/008895570",
	"FRE":   "http://irail.be/stations/NMBS/008895646",
	"FRH":   "http://irail.be/stations/NMBS/008884640",
	"FRL":   "http://irail.be/stations/NMBS/008896800",
	"FRMB":  "http://irail.be/stations/NMBS/008895091",
	"FRN":   "http://irail.be/stations/NMBS/008892908",
	"FRP":   "http://irail.be/stations/NMBS/008822715",
	"FRPM":  "http://irail.be/stations/NMBS/008895471",
	"FRSP":  "http://irail.be/stations/NMBS/008891033",
	"FRST":  "http://irail.be/stations/NMBS/008833209",
	"FRT":   "http://irail.be/stations/NMBS/008891314",
	"FRU":   "http://irail.be/stations/NMBS/008895455",
	"FRX":   "http://irail.be/stations/NMBS/008871217",
	"FRZ":   "http://irail.be/stations/NMBS/008844271",
	"FSB":   "http://irail.be/stations/NMBS/008884319",
	"FSD":   "http://irail.be/stations/NMBS/008891702",
	"FSG":   "http://irail.be/stations/NMBS/008883113",
	"FSK":   "http://irail.be/stations/NMBS/008893070",
	"FSMB":  "http://irail.be/stations/NMBS/008812245",
	"FSN":   "http://irail.be/stations/NMBS/008894508",
	"FSR":   "http://irail.be/stations/NMBS/008811007",
	"FSSG":  "http://irail.be/stations/NMBS/008844420",
	"FST":   "http://irail.be/stations/NMBS/008831807",
	"FSV":   "http://irail.be/stations/NMBS/008822848",
	"FTB":   "http://irail.be/stations/NMBS/008811254",
	"FTE":   "http://irail.be/stations/NMBS/008814134",
	"FTG":   "http://irail.be/stations/NMBS/008831310",
	"FTI":   "http://irail.be/stations/NMBS/008841319",
	"FTK":   "http://irail.be/stations/NMBS/008892403",
	"FTM":   "http://irail.be/stations/NMBS/008874609",
	"FTN":   "http://irail.be/stations/NMBS/008812252",
	"FTNN":  "http://irail.be/stations/NMBS/008833308",
	"FTR":   "http://irail.be/stations/NMBS/008821907",
	"FTS":   "http://irail.be/stations/NMBS/008894672",
	"FTT":   "http://irail.be/stations/NMBS/008892254",
	"FTU":   "http://irail.be/stations/NMBS/008871811",
	"FTU":   "http://irail.be/stations/NMBS/008884350",
	"FTX":   "http://irail.be/stations/NMBS/008844339",
	"FTY":   "http://irail.be/stations/NMBS/008885001",
	"FTZ":   "http://irail.be/stations/NMBS/008883808",
	"FUGE":  "http://irail.be/stations/NMBS/008893179",
	"FUS":   "http://irail.be/stations/NMBS/008814126",
	"FUS":   "http://irail.be/stations/NMBS/008886074",
	"FVE":   "http://irail.be/stations/NMBS/008896230",
	"FVG":   "http://irail.be/stations/NMBS/008896149",
	"FVI":   "http://irail.be/stations/NMBS/008845146",
	"FVK":   "http://irail.be/stations/NMBS/008833050",
	"FVL":   "http://irail.be/stations/NMBS/008874716",
	"FVP":   "http://irail.be/stations/NMBS/008822525",
	"FVR":   "http://irail.be/stations/NMBS/008841400",
	"FVS":   "http://irail.be/stations/NMBS/008846201",
	"FVT":   "http://irail.be/stations/NMBS/008893559",
	"FVU":   "http://irail.be/stations/NMBS/008892304",
	"FVV":   "http://irail.be/stations/NMBS/008811189",
	"FVY":   "http://irail.be/stations/NMBS/008845005",
	"FW":    "http://irail.be/stations/NMBS/008811429",
	"FWA":   "http://irail.be/stations/NMBS/008822228",
	"FWB":   "http://irail.be/stations/NMBS/008822608",
	"FWE":   "http://irail.be/stations/NMBS/008822251",
	"FWG":   "http://irail.be/stations/NMBS/008833175",
	"FWI":   "http://irail.be/stations/NMBS/008833670",
	"FWM":   "http://irail.be/stations/NMBS/008896370",
	"FWO":   "http://irail.be/stations/NMBS/008893211",
	"FWT":   "http://irail.be/stations/NMBS/008814266",
	"FXA":   "http://irail.be/stations/NMBS/008886546",
	"FXB":   "http://irail.be/stations/NMBS/008871332",
	"FXH":   "http://irail.be/stations/NMBS/008841467",
	"FXR":   "http://irail.be/stations/NMBS/008886587",
	"FXS":   "http://irail.be/stations/NMBS/008885753",
	"FYP":   "http://irail.be/stations/NMBS/008881174",
	"FZ":    "http://irail.be/stations/NMBS/008894235",
	"FZA":   "http://irail.be/stations/NMBS/008811221",
	"FZB":   "http://irail.be/stations/NMBS/008895737",
	"FZE":   "http://irail.be/stations/NMBS/008833449",
	"FZG":   "http://irail.be/stations/NMBS/008892635",
	"FZI":   "http://irail.be/stations/NMBS/008812062",
	"FZL":   "http://irail.be/stations/NMBS/008822111",
	"FZM":   "http://irail.be/stations/NMBS/008893062",
	"FZT":   "http://irail.be/stations/NMBS/008895208",
	"FZY":   "http://irail.be/stations/NMBS/008861333",
	"GB":    "http://irail.be/stations/NMBS/008821857",
	"GBC":   "http://irail.be/stations/NMBS/008821634",
	"GBD":   "http://irail.be/stations/NMBS/008821865",
	"GBL":   "http://irail.be/stations/NMBS/008821816",
	"GDP":   "http://irail.be/stations/NMBS/008831112",
	"GFL":   "http://irail.be/stations/NMBS/008811767",
	"GFY":   "http://irail.be/stations/NMBS/008885068",
	"GG":    "http://irail.be/stations/NMBS/008811742",
	"GHA":   "http://irail.be/stations/NMBS/008832664",
	"GHE":   "http://irail.be/stations/NMBS/008833126",
	"GHO":   "http://irail.be/stations/NMBS/008821832",
	"GHT":   "http://irail.be/stations/NMBS/008811155",
	"GJ":    "http://irail.be/stations/NMBS/008871175",
	"GKT":   "http://irail.be/stations/NMBS/008821451",
	"GLM":   "http://irail.be/stations/NMBS/008811635",
	"GLR":   "http://irail.be/stations/NMBS/008872587",
	"GMO":   "http://irail.be/stations/NMBS/008821147",
	"GMOG":  "http://irail.be/stations/NMBS/008821238",
	"GNS":   "http://irail.be/stations/NMBS/008821022",
	"GOL":   "http://irail.be/stations/NMBS/008832458",
	"GPL":   "http://irail.be/stations/NMBS/008873122",
	"GSU":   "http://irail.be/stations/NMBS/008831088",
	"GSW":   "http://irail.be/stations/NMBS/008833159",
	"GTI":   "http://irail.be/stations/NMBS/008872553",
	"GTT":   "http://irail.be/stations/NMBS/008833266",
	"GV":    "http://irail.be/stations/NMBS/008844008",
	"GVH":   "http://irail.be/stations/NMBS/008833134",
	"GVX":   "http://irail.be/stations/NMBS/008841327",
	"GWD":   "http://irail.be/stations/NMBS/008821436",
	"GWK":   "http://irail.be/stations/NMBS/008844503",
	"GWV":   "http://irail.be/stations/NMBS/008811726",
	"GZC":   "http://irail.be/stations/NMBS/008833274",
	"HARZ":  "http://irail.be/stations/NMBS/008811130",
	"LAS":   "http://irail.be/stations/NMBS/008812070",
	"LBG":   "http://irail.be/stations/NMBS/008832003",
	"LBG":   "http://irail.be/stations/NMBS/008861200",
	"LBH":   "http://irail.be/stations/NMBS/008882362",
	"LBM":   "http://irail.be/stations/NMBS/008891124",
	"LBN":   "http://irail.be/stations/NMBS/008832235",
	"LBQ":   "http://irail.be/stations/NMBS/008881463",
	"LBV":   "http://irail.be/stations/NMBS/008864451",
	"LBZ":   "http://irail.be/stations/NMBS/008873320",
	"LC":    "http://irail.be/stations/NMBS/008864501",
	"LCCM":  "http://irail.be/stations/NMBS/008871225",
	"LCL":   "http://irail.be/stations/NMBS/008874054",
	"LCN":   "http://irail.be/stations/NMBS/008811825",
	"LCV":   "http://irail.be/stations/NMBS/008875127",
	"LDS":   "http://irail.be/stations/NMBS/008872306",
	"LEK":   "http://irail.be/stations/NMBS/008821659",
	"LEM":   "http://irail.be/stations/NMBS/008811247",
	"LEZ":   "http://irail.be/stations/NMBS/008812153",
	"LFC":   "http://irail.be/stations/NMBS/008871514",
	"LFH":   "http://irail.be/stations/NMBS/008843208",
	"LFR":   "http://irail.be/stations/NMBS/008872413",
	"LG":    "http://irail.be/stations/NMBS/008832433",
	"LGL":   "http://irail.be/stations/NMBS/008841731",
	"LGR":   "http://irail.be/stations/NMBS/008843174",
	"LHH":   "http://irail.be/stations/NMBS/008873387",
	"LHL":   "http://irail.be/stations/NMBS/008812112",
	"LHM":   "http://irail.be/stations/NMBS/008842846",
	"LHR":   "http://irail.be/stations/NMBS/008881430",
	"LHS":   "http://irail.be/stations/NMBS/008841608",
	"LHY":   "http://irail.be/stations/NMBS/008843406",
	"LJ":    "http://irail.be/stations/NMBS/008864006",
	"LJ":    "http://irail.be/stations/NMBS/008884566",
	"LJP":   "http://irail.be/stations/NMBS/008843158",
	"LK":    "http://irail.be/stations/NMBS/008896008",
	"LKD":   "http://irail.be/stations/NMBS/008895836",
	"LKM":   "http://irail.be/stations/NMBS/008824224",
	"LKN":   "http://irail.be/stations/NMBS/008814142",
	"LKP":   "http://irail.be/stations/NMBS/008821535",
	"LKR":   "http://irail.be/stations/NMBS/008821071",
	"LL":    "http://irail.be/stations/NMBS/008866001",
	"LLB":   "http://irail.be/stations/NMBS/008894433",
	"LLE":   "http://irail.be/stations/NMBS/008872579",
	"LLT":   "http://irail.be/stations/NMBS/008884715",
	"LM":    "http://irail.be/stations/NMBS/008894755",
	"LMG":   "http://irail.be/stations/NMBS/008875002",
	"LMH":   "http://irail.be/stations/NMBS/008866175",
	"LML":   "http://irail.be/stations/NMBS/008832409",
	"LMZ":   "http://irail.be/stations/NMBS/008882230",
	"LNE":   "http://irail.be/stations/NMBS/008832045",
	"LNG":   "http://irail.be/stations/NMBS/008866258",
	"LNI":   "http://irail.be/stations/NMBS/008824240",
	"LNK":   "http://irail.be/stations/NMBS/008822343",
	"LNM":   "http://irail.be/stations/NMBS/008881315",
	"LNO":   "http://irail.be/stations/NMBS/008811676",
	"LNP":   "http://irail.be/stations/NMBS/008832615",
	"LNS":   "http://irail.be/stations/NMBS/008871712",
	"LNS":   "http://irail.be/stations/NMBS/008882248",
	"LOB":   "http://irail.be/stations/NMBS/008822772",
	"LOK":   "http://irail.be/stations/NMBS/008895638",
	"LOL":   "http://irail.be/stations/NMBS/008832565",
	"LOT":   "http://irail.be/stations/NMBS/008814357",
	"LPT":   "http://irail.be/stations/NMBS/008871415",
	"LQ":    "http://irail.be/stations/NMBS/008871605",
	"LQV":   "http://irail.be/stations/NMBS/008881505",
	"LRB":   "http://irail.be/stations/NMBS/008865003",
	"LRG":   "http://irail.be/stations/NMBS/008881406",
	"LRS":   "http://irail.be/stations/NMBS/008881570",
	"LS":    "http://irail.be/stations/NMBS/008865110",
	"LSD":   "http://irail.be/stations/NMBS/008893260",
	"LSL":   "http://irail.be/stations/NMBS/008841673",
	"LSN":   "http://irail.be/stations/NMBS/008842663",
	"LSW":   "http://irail.be/stations/NMBS/008894425",
	"LT":    "http://irail.be/stations/NMBS/008811601",
	"LTM":   "http://irail.be/stations/NMBS/008841665",
	"LU":    "http://irail.be/stations/NMBS/008881455",
	"LUH":   "http://irail.be/stations/NMBS/008873379",
	"LVL":   "http://irail.be/stations/NMBS/008882339",
	"LVR":   "http://irail.be/stations/NMBS/008882107",
	"LVRS":  "http://irail.be/stations/NMBS/008882206",
	"LWC":   "http://irail.be/stations/NMBS/008873007",
	"LWK":   "http://irail.be/stations/NMBS/008896396",
	"LWT":   "http://irail.be/stations/NMBS/008893815",
	"LX":    "http://irail.be/stations/NMBS/008811304",
	"LZD":   "http://irail.be/stations/NMBS/008894821",
	"LZE":   "http://irail.be/stations/NMBS/008891553",
	"LZES":  "http://irail.be/stations/NMBS/008891173",
	"LZG":   "http://irail.be/stations/NMBS/008896909",
	"LZH":   "http://irail.be/stations/NMBS/008832334",
	"LZM":   "http://irail.be/stations/NMBS/008891264",
	"MAB":   "http://irail.be/stations/NMBS/008866654",
	"MAP":   "http://irail.be/stations/NMBS/008895745",
	"MAS":   "http://irail.be/stations/NMBS/008864931",
	"MAU":   "http://irail.be/stations/NMBS/008885530",
	"MBG":   "http://irail.be/stations/NMBS/008863867",
	"MBL":   "http://irail.be/stations/NMBS/008861531",
	"MBM":   "http://irail.be/stations/NMBS/008864469",
	"MBR":   "http://irail.be/stations/NMBS/008811437",
	"MBX":   "http://irail.be/stations/NMBS/008865300",
	"MBZ":   "http://irail.be/stations/NMBS/008861424",
	"MC":    "http://irail.be/stations/NMBS/008861523",
	"MCH":   "http://irail.be/stations/NMBS/008864410",
	"MCL":   "http://irail.be/stations/NMBS/008865565",
	"MCM":   "http://irail.be/stations/NMBS/008811817",
	"MCT":   "http://irail.be/stations/NMBS/008842838",
	"MD":    "http://irail.be/stations/NMBS/008861432",
	"MDL":   "http://irail.be/stations/NMBS/008811445",
	"MDT":   "http://irail.be/stations/NMBS/008863362",
	"MEE":   "http://irail.be/stations/NMBS/008895877",
	"MFL":   "http://irail.be/stations/NMBS/008866845",
	"MFR":   "http://irail.be/stations/NMBS/008864311",
	"MFX":   "http://irail.be/stations/NMBS/008872611",
	"MG":    "http://irail.be/stations/NMBS/008865649",
	"MGA":   "http://irail.be/stations/NMBS/008812229",
	"MGD":   "http://irail.be/stations/NMBS/008865615",
	"MGN":   "http://irail.be/stations/NMBS/008863834",
	"MGP":   "http://irail.be/stations/NMBS/008864337",
	"MGR":   "http://irail.be/stations/NMBS/008842002",
	"MGV":   "http://irail.be/stations/NMBS/008811528",
	"MH":    "http://irail.be/stations/NMBS/008866605",
	"MHB":   "http://irail.be/stations/NMBS/008866142",
	"MHD":   "http://irail.be/stations/NMBS/008832243",
	"MHM":   "http://irail.be/stations/NMBS/008861168",
	"MHO":   "http://irail.be/stations/NMBS/008821337",
	"MHV":   "http://irail.be/stations/NMBS/008864832",
	"MHY":   "http://irail.be/stations/NMBS/008863842",
	"MHZ":   "http://irail.be/stations/NMBS/008866530",
	"MID":   "http://irail.be/stations/NMBS/008821519",
	"MIM":   "http://irail.be/stations/NMBS/008896388",
	"MJS":   "http://irail.be/stations/NMBS/008863354",
	"MKM":   "http://irail.be/stations/NMBS/008862018",
	"ML":    "http://irail.be/stations/NMBS/008811510",
	"MLG":   "http://irail.be/stations/NMBS/008864816",
	"MLR":   "http://irail.be/stations/NMBS/008864436",
	"MLY":   "http://irail.be/stations/NMBS/008881562",
	"MLZ":   "http://irail.be/stations/NMBS/008861416",
	"MM":    "http://irail.be/stations/NMBS/008861549",
	"MML":   "http://irail.be/stations/NMBS/008864345",
	"MNG":   "http://irail.be/stations/NMBS/008861515",
	"MNK":   "http://irail.be/stations/NMBS/008895232",
	"MNN":   "http://irail.be/stations/NMBS/008864964",
	"MNS":   "http://irail.be/stations/NMBS/008863818",
	"MNT":   "http://irail.be/stations/NMBS/008864915",
	"MO":    "http://irail.be/stations/NMBS/008841459",
	"MPL":   "http://irail.be/stations/NMBS/008865540",
	"MPS":   "http://irail.be/stations/NMBS/008842689",
	"MPX":   "http://irail.be/stations/NMBS/008865227",
	"MRB":   "http://irail.be/stations/NMBS/008821543",
	"MRN":   "http://irail.be/stations/NMBS/008861440",
	"MRP":   "http://irail.be/stations/NMBS/008811262",
	"MRR":   "http://irail.be/stations/NMBS/008864949",
	"MRV":   "http://irail.be/stations/NMBS/008842705",
	"MRX":   "http://irail.be/stations/NMBS/008811536",
	"MSM":   "http://irail.be/stations/NMBS/008866407",
	"MTB":   "http://irail.be/stations/NMBS/008811411",
	"MTF":   "http://irail.be/stations/NMBS/008842630",
	"MTH":   "http://irail.be/stations/NMBS/008895448",
	"MWC":   "http://irail.be/stations/NMBS/008821824",
	"MWL":   "http://irail.be/stations/NMBS/008842754",
	"MX":    "http://irail.be/stations/NMBS/008892320",
	"MY":    "http://irail.be/stations/NMBS/008866662",
	"MZD":   "http://irail.be/stations/NMBS/008832250",
	"NA":    "http://irail.be/stations/NMBS/008843323",
	"NBE":   "http://irail.be/stations/NMBS/008843430",
	"NDK":   "http://irail.be/stations/NMBS/008821105",
	"NDKMP": "http://irail.be/stations/NMBS/008821105",
	"NDN":   "http://irail.be/stations/NMBS/008863404",
	"NDT":   "http://irail.be/stations/NMBS/008863503",
	"NFG":   "http://irail.be/stations/NMBS/008843166",
	"NFV":   "http://irail.be/stations/NMBS/008871688",
	"NG":    "http://irail.be/stations/NMBS/008843240",
	"NGD":   "http://irail.be/stations/NMBS/008863560",
	"NJ":    "http://irail.be/stations/NMBS/008863115",
	"NL":    "http://irail.be/stations/NMBS/008871837",
	"NLB":   "http://irail.be/stations/NMBS/008871670",
	"NLT":   "http://irail.be/stations/NMBS/008863156",
	"NM":    "http://irail.be/stations/NMBS/008843331",
	"NMD":   "http://irail.be/stations/NMBS/008863461",
	"NMH":   "http://irail.be/stations/NMBS/008863453",
	"NOKMP": "http://irail.be/stations/NMBS/008821105",
	"NS":    "http://irail.be/stations/NMBS/008863446",
	"NSN":   "http://irail.be/stations/NMBS/008843133",
	"NSR":   "http://irail.be/stations/NMBS/008843067",
	"NSS":   "http://irail.be/stations/NMBS/008871662",
	"NTH":   "http://irail.be/stations/NMBS/008871811",
	"NV":    "http://irail.be/stations/NMBS/008863545",
	"NY":    "http://irail.be/stations/NMBS/008843307",
	"NZ":    "http://irail.be/stations/NMBS/008871852",
	"PRY":   "http://irail.be/stations/NMBS/008873312",
	"REG":   "http://irail.be/stations/NMBS/008844644",
	"REP":   "http://irail.be/stations/NMBS/008844628",
	"XBSP":  "http://irail.be/stations/NMBS/008844404",
	"ZWA":   "http://irail.be/stations/NMBS/008891611"
}
